@@ -1,7 +1,7 @@
 //
 // C++ Interface: enums
 //
-// Description: 
+// Description:
 //
 //
 // Author: Andre Simon <andre.simon1@gmx.de>, (C) 2004
@@ -15,32 +15,28 @@
 
 namespace highlight {
 
+/** states which may occour during input file parsing*/
 enum State {
   STANDARD=0,
-  KEYWORD,
-  TYPE,
   STRING,
   NUMBER,
-  SINGLE_LINE_COMMENT,
-  MULTI_LINE_COMMENT_BEGIN,
+  SL_COMMENT,
+  ML_COMMENT_BEGIN,
   ESC_CHAR,
   DIRECTIVE_LINE,
   DIRECTIVE_STRING,
   LINENUMBER,
-  SYMBOL, 
+  SYMBOL,
 
   // Konstanten ab hier duefen nicht mehr als Array-Indizes benutzt werden!!
-  MULTI_LINE_COMMENT_END,
-  STRING_END,
+  KEYWORD,
+  ML_COMMENT_END,
   DIRECTIVE_LINE_END,
   TAG_BEGIN,
   TAG_END,
-  MEMBER_ATTRIBUTE_BEGIN,
-  MEMBER_ATTRIBUTE_END,
   KEYWORD_BEGIN,
   KEYWORD_END,
-  TYPE_BEGIN,
-  TYPE_END,
+  ESC_CHAR_EXT,  // escape character outside of strings
 
   _UNKNOWN=100,
   _EOL,
@@ -48,34 +44,39 @@ enum State {
   _WS
 } ;
 
+/** Parser return values*/
 enum ParseError{
    PARSE_OK,
-   BAD_INPUT,
-   BAD_OUTPUT,
-   BAD_STYLE
-};
-
-enum FormatStyle {
-  FORMAT_DISABLED = 0,
-  FORMAT_ANSI,
-  FORMAT_GNU,
-  FORMAT_JAVA,
-  FORMAT_KR,
-  FORMAT_LINUX 
+   BAD_INPUT=1,
+   BAD_OUTPUT=2,
+   BAD_STYLE=4
 };
 
+/** line wrapping modes*/
 enum WrapMode {
   WRAP_DISABLED,
   WRAP_SIMPLE,
   WRAP_DEFAULT
 };
 
-enum LoadResult{    
+/** language definition loading results*/
+enum LoadResult{
   LOAD_FAILED,
   LOAD_NEW,
   LOAD_NONE
 };
 
+/** output formats */
+enum OutputType {
+  HTML,
+  XHTML,
+  TEX,
+  LATEX,
+  RTF,
+  XSLFO,
+  ANSI
+};
+
 
 }
 
